# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class BrainStructure(str, Enum):
    """
    BrainStructure
    """

    """
    allowed enum values
    """
    AMYGDALOID_COMPLEX = "amygdaloid complex"
    ANSA_LENTICULARIS = "ansa lenticularis"
    ARACHNOID_MATER = "arachnoid mater"
    ARBOR_VITAE = "arbor vitae"
    ARCUATE_FASCICULUS = "arcuate fasciculus"
    BASILAR_ARTERY = "basilar artery"
    BASONUCLEUS_AMYGDALA = "basonucleus amygdala"
    BERGMANN_GLIA = "bergmann glia"
    BERNASCONI_VEIN = "bernasconi vein"
    BLOOD_BRAIN_BARRIER = "blood brain barrier"
    BLOOD_VESSELS = "blood vessels"
    BODY_OF_FORNIX = "body of fornix"
    BRACHIUM_CONJUNCTIVUM = "brachium conjunctivum"
    BRAIN_BARRIER_SYSTEM = "brain barrier system"
    CA1 = "ca1"
    CA2 = "ca2"
    CA3 = "ca3"
    CA4 = "ca4"
    CALCARINE_SULCUS = "calcarine sulcus"
    CALLOSAL_SULCUS = "callosal sulcus"
    CALLOSOMARGINAL_ARTERY = "callosomarginal artery"
    CAUDATE = "caudate"
    CAUDATE_NUCLEUS = "caudate nucleus"
    CAVERNOSUS_SINUS = "cavernosus sinus"
    CAVE_OF_RETZIUS = "cave of retzius"
    CENTRAL_ARTERY = "central artery"
    CENTRAL_CANAL = "central canal"
    CENTRAL_LOBULE = "central lobule"
    CENTRAL_NUCLEUS_AMYGDALA = "central nucleus amygdala"
    CEREBELLAR_ARTERY = "cerebellar artery"
    CEREBELLAR_CORTEX = "cerebellar cortex"
    CEREBELLAR_NUCLEI = "cerebellar nuclei"
    CEREBELLAR_TONSIL = "cerebellar tonsil"
    CEREBELLAR_PEDUNCLES = "cerebellar peduncles"
    CEREBELLAR_PEDUNCLES_MIDDLE = "cerebellar peduncles middle"
    CEREBELLAR_VESSELS = "cerebellar vessels"
    CEREBELLAR_WHITE_MATTER = "cerebellar white matter"
    CEREBRAL_AQUEDUCT = "cerebral aqueduct"
    CEREBRAL_ARTERY = "cerebral artery"
    CEREBRAL_ENDOTHELIAL_CELL = "cerebral endothelial cell"
    CEREBRAL_VEIN = "cerebral vein"
    CEREBRAL_VESSELS = "cerebral vessels"
    CEREBROSPINAL_FLUID = "cerebrospinal fluid"
    CHOROIDAL_ARTERY = "choroidal artery"
    CHOROID_PLEXUS = "choroid plexus"
    CHOROID_PLEXUS_EPITHELIUM = "choroid plexus epithelium"
    CHOROID_PLEXUS_VESSELS = "choroid plexus vessels"
    CINGULATE = "cingulate"
    CINGULUM = "cingulum"
    CIRCLE_OF_WILLIS = "circle of willis"
    CIRCUMFLEX_FASCICULUS = "circumflex fasciculus"
    COLICULUS = "coliculus"
    COLSULCUS = "colsulcus"
    COLUMN_OF_FORNIX = "column of fornix"
    COMMISSURE = "commissure"
    COMMISSURE_WHITE_MATTER = "commissure white matter"
    COMMISURE = "commisure"
    COMMUNICATING_ARTERY = "communicating artery"
    CORPUS_CALLOSUM_BODY = "corpus callosum body"
    CORPUS_CALLOSUM_GENU = "corpus callosum genu"
    CORPUS_CALLOSUM_ROSTRUM = "corpus callosum rostrum"
    CORPUS_CALLOSUM_SPLENIUM = "corpus callosum splenium"
    CORTEX = "cortex"
    CORTICAL_NUCLEUS_AMYGDALA = "cortical nucleus amygdala"
    CORTICOSPINAL_TRACT = "corticospinal tract"
    CRUS_CEREBRI = "crus cerebri"
    CRUS_OF_FORNIX = "crus of fornix"
    CULMEN = "culmen"
    CULMEN_VERMIS = "culmen vermis"
    CUNEUS = "cuneus"
    DECLIVE = "declive"
    DECLIVE_VERMIS = "declive vermis"
    DENDRITE = "dendrite"
    DENTATE_GYRUS = "dentate gyrus"
    DENTATE_GYRUS_SULCUS = "dentate gyrus sulcus"
    DENTATE_NUCLEUS = "dentate nucleus"
    DG = "dg"
    DIAGONAL_BAND_OF_BROCA = "diagonal band of broca"
    DURA_MATER = "dura mater"
    EMBOLIFORM_NUCLEUS = "emboliform nucleus"
    ENTORHINAL_CORTEX = "entorhinal cortex"
    EPENDYMAL_CELL = "ependymal cell"
    EPENDYMOGLIA = "ependymoglia"
    FASTIGIAL_NUCLEUS = "fastigial nucleus"
    FASTIGIUM = "fastigium"
    FIBROUS_ASTROCYTE = "fibrous astrocyte"
    FIMBRIA = "fimbria"
    FISSURE_OF_SYLVIUS = "fissure of sylvius"
    FLOCCULONODULAR_LOBE = "flocculonodular lobe"
    FLOCCULUS = "flocculus"
    FOLLICULI = "folliculi"
    FORAMEN_OF_MONRO = "foramen of monro"
    FORCEPS_MAJOR = "forceps major"
    FORCEPS_MINOR = "forceps minor"
    FOURTH_VENTRICLE = "fourth ventricle"
    FRONTAL_GYRUS = "frontal gyrus"
    FRONTAL_SULCUS = "frontal sulcus"
    FRONTOPOLAR_ARTERY = "frontopolar artery"
    FUNICULUSIS = "funiculusis"
    GENICULATE_NUCLEUS = "geniculate nucleus"
    GLOBOSE_NUCLEUS = "globose nucleus"
    GLOBUS_PALLIDUS = "globus pallidus"
    HABENULA = "habenula"
    HABENULAR_COMMISURE = "habenular commisure"
    HIPPOCAMPAL_SULCUS = "hippocampal sulcus"
    HIPPOCAMPUS = "hippocampus"
    HYPOTHALAMIC_COMMISSURE = "hypothalamic commissure"
    HYPOTHALAMIC_COMMISURE = "hypothalamic commisure"
    INDUSEUM_GRISIUM = "induseum grisium"
    INFUNDIBULUM = "infundibulum"
    INTERCALATED_NUCLEUS_AMYGDALA = "intercalated nucleus amygdala"
    INTERIOR_CEREBRAL_VEIN = "interior cerebral vein"
    INTERNAL_CAPSULE_GENU = "internal capsule genu"
    INTERNAL_CAPSULE_LIMB = "internal capsule limb"
    INTERNAL_CAROTID_ARTERY = "internal carotid artery"
    INTERPEDUNCULAR_FOSSA = "interpeduncular fossa"
    INTERPOSITUS_NUCLEUS = "interpositus nucleus"
    INTERVENTRICULAR_FORAMEN = "interventricular foramen"
    INTRALAMINAR_NUCLEUS_THALAMUS = "intralaminar nucleus thalamus"
    LAMINA_TERMINALIS = "lamina terminalis"
    LATERONUCLEUS = "lateronucleus"
    LEMNISCUS = "lemniscus"
    LENTICULAR_FASCICULUS = "lenticular fasciculus"
    LENTICULOSTRIATE_ARTERIES = "lenticulostriate arteries"
    LINGUAL_GYRUS = "lingual gyrus"
    LINGUAL_SULCUS = "lingual sulcus"
    LONGITUDINAL_FASCICULUS = "longitudinal fasciculus"
    LUSHKA_FORAMEN = "lushka foramen"
    MAGENDIE_FORAMEN = "magendie foramen"
    MAMMILLARY_BODY = "mammillary body"
    MAMMILLARY_RECESS = "mammillary recess"
    MASSA_INTERMEDIA = "massa intermedia"
    MEDULLARY_RETICULOSPINAL_TRACT = "medullary reticulospinal tract"
    MEDULLARY_VELUM = "medullary velum"
    MENINGEAL_VESSELS = "meningeal vessels"
    MIDDLE_CEREBRAL_ARTERY = "middle cerebral artery"
    MIDDLE_CEREBRAL_VEIN = "middle cerebral vein"
    MIDDLE_TEMPORAL_GYRUS = "middle temporal gyrus"
    MIDLINE_NUCLEUS_THALAMUS = "midline nucleus thalamus"
    NUCLEUS_AMYGDALA = "nucleus amygdala"
    NUCLEUS_THALAMUS = "nucleus thalamus"
    NUCLEUS_ACCUMBENS = "nucleus accumbens"
    OCCIPITAL_GYRUS = "occipital gyrus"
    OCCIPITAL_SINUS = "occipital sinus"
    OCCIPITAL_SULCUS = "occipital sulcus"
    OCCIPITOTEMPORAL_GYRUS = "occipitotemporal gyrus"
    OCCIPITOTEMPORAL_SULCUS = "occipitotemporal sulcus"
    OLFACTORY_SULCUS = "olfactory sulcus"
    OLFACTORY_TRIGONE = "olfactory trigone"
    OLIGODENDROCYTE = "oligodendrocyte"
    OLIVARY_COMPLEX = "olivary complex"
    OLIVOSPINAL_TRACT = "olivospinal tract"
    OPHTHALMIC_ARTERY = "ophthalmic artery"
    OPTIC_CHIASM = "optic chiasm"
    OPTIC_NERVE = "optic nerve"
    OPTIC_RECESS = "optic recess"
    ORBIFRONTAL_GYRUS = "orbifrontal gyrus"
    ORBITOFRONTAL_ARTERY = "orbitofrontal artery"
    ORBITOFRONTAL_CORTEX = "orbitofrontal cortex"
    PARACENTRAL_LOBULE = "paracentral lobule"
    PARAFLOCCULUS = "paraflocculus"
    PARAHIPPOCAMPAL_GYRUS = "parahippocampal gyrus"
    PARAVENTRICULAR_NUCLEUS_THALAMUS = "paraventricular nucleus thalamus"
    PARENCHYMAL_FEET = "parenchymal feet"
    PARIETAL_GYRUS = "parietal gyrus"
    PARIETAL_LOBE = "parietal lobe"
    PARIETAL_LOBULE = "parietal lobule"
    PARIETAL_OPERCULUM = "parietal operculum"
    PARIETO_OCCIPITAL_ARTERY = "parieto occipital artery"
    PARIETO_OCCIPITAL_NOTCH = "parieto occipital notch"
    PARIETO_OCCIPITAL_SULCUS = "parieto occipital sulcus"
    PARS_OPERCULARIS = "pars opercularis"
    PARS_ORBITALIS = "pars orbitalis"
    PARS_TRIANGULARIS = "pars triangularis"
    PEDUNCULOPONTINE_NUCLEUS = "pedunculopontine nucleus"
    PERFORATED_SUBSTANCE = "perforated substance"
    PERICALLOSAL_ARTERY = "pericallosal artery"
    PERIRHINAL_CORTEX = "perirhinal cortex"
    PETROSAL_SINUS = "petrosal sinus"
    PIASTROCYTE = "piastrocyte"
    PIA_MATER = "pia mater"
    PINEALOCYTE = "pinealocyte"
    PINEAL_GYRUS = "pineal gyrus"
    PINEAL_RECESS = "pineal recess"
    PITUICYTE = "pituicyte"
    PITUITARY_GYRUS = "pituitary gyrus"
    PONS = "pons"
    PONTINE_FIBERS = "pontine fibers"
    PONTINE_RETICULOSPINAL_TRACT = "pontine reticulospinal tract"
    POSTCENTRAL_ARTERY = "postcentral artery"
    POSTCENTRAL_GYRUS = "postcentral gyrus"
    PRECENTRAL_ARTERY = "precentral artery"
    PRECENTRAL_GYRUS = "precentral gyrus"
    PRECENTRAL_SULCUS = "precentral sulcus"
    PRECUNEUS = "precuneus"
    PREMOTOR_CORTEX = "premotor cortex"
    PREOPTIC_AREA = "preoptic area"
    PREPYRIFORM_AREA = "prepyriform area"
    PRESUBICULUM = "presubiculum"
    PRIMARY_AUDITORY_CORTEX = "primary auditory cortex"
    PRIMARY_FISSURE = "primary fissure"
    PRIMARY_MOTOR_CORTEX = "primary motor cortex"
    PRIMARY_SENSORY_CORTEX = "primary sensory cortex"
    PRIMARY_SOMATOSENSORY_CORTEX = "primary somatosensory cortex"
    PRIMARY_VISUAL_CORTEX = "primary visual cortex"
    PRIMAR_VISUAL_CORTEX = "primar visual cortex"
    PROSUBICULUM = "prosubiculum"
    PROTOPLASMIC_ASTROCYTE = "protoplasmic astrocyte"
    PULVINAR = "pulvinar"
    PULVINAR_NUCLEUS = "pulvinar nucleus"
    PUTAMEN = "putamen"
    PYRAMIDAL_CELL = "pyramidal cell"
    PYRAMIDAL_TRACT = "pyramidal tract"
    PYRAMIS = "pyramis"
    PYRAMIS_VERMIS = "pyramis vermis"
    RADIAL_GLIA = "radial glia"
    RECESS = "recess"
    RECURRENT_ARTERY_OF_HEBERDEN = "recurrent artery of heberden"
    RED_NUCLEUS = "red nucleus"
    RETICULAR_FORMATION = "reticular formation"
    RETICULAR_NUCLEUS = "reticular nucleus"
    RETICULAR_NUCLEUS_THALAMUS = "reticular nucleus thalamus"
    RETROLENFICULAR_PART = "retrolenficular part"
    RETROSPLENIAL_CORTEX = "retrosplenial cortex"
    RHINAL_SULCUS = "rhinal sulcus"
    RHOMBIC_LIP = "rhombic lip"
    ROSSENTHAL_VEIN = "rossenthal vein"
    RUBROSPINAL_TRACT = "rubrospinal tract"
    SAGITTAL_SINUS = "sagittal sinus"
    SECONDARY_AUDITORY_CORTEX = "secondary auditory cortex"
    SECONDARY_SOMATOSENSORY_CORTEX = "secondary somatosensory cortex"
    SECONDARY_VISUAL_CORTEX = "secondary visual cortex"
    SEPTAL_NUCLEUS = "septal nucleus"
    SEPTUM = "septum"
    SEPTUM_PELLUCIDUM = "septum pellucidum"
    SEPTUM_VERUM = "septum verum"
    SHORT_CINGULATE_GYRUS = "short cingulate gyrus"
    SHORT_INSULAR_GYRUS = "short insular gyrus"
    SIGMOID_SINUS = "sigmoid sinus"
    SILVIAN_FISSURE = "silvian fissure"
    SIMPLE_LOBULE = "simple lobule"
    SINGULATE = "singulate"
    SINGULATE_GYRUS = "singulate gyrus"
    SINGULATE_SULCUS = "singulate sulcus"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BrainStructure from a JSON string"""
        return cls(json.loads(json_str))
