# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, StrictStr
from syndb_api_client.models.multi_brain_region_dataset_definition import MultiBrainRegionDatasetDefinition
from syndb_api_client.models.single_dataset_schema_no_brain_region import SingleDatasetSchemaNoBrainRegion
from typing_extensions import Self


class CreateDatasetCollectionMultiBrainRegion(BaseModel):
    """
    CreateDatasetCollectionMultiBrainRegion
    """  # noqa: E501

    authorized_group_names: Optional[List[StrictStr]] = None
    name: StrictStr
    notes: Optional[StrictStr] = None
    dataset_definition: List[MultiBrainRegionDatasetDefinition]
    dataset_metadata: SingleDatasetSchemaNoBrainRegion
    __properties: ClassVar[List[str]] = [
        "authorized_group_names",
        "name",
        "notes",
        "dataset_definition",
        "dataset_metadata",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateDatasetCollectionMultiBrainRegion from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in dataset_definition (list)
        _items = []
        if self.dataset_definition:
            for _item in self.dataset_definition:
                if _item:
                    _items.append(_item.to_dict())
            _dict["dataset_definition"] = _items
        # override the default output from pydantic by calling `to_dict()` of dataset_metadata
        if self.dataset_metadata:
            _dict["dataset_metadata"] = self.dataset_metadata.to_dict()
        # set to None if authorized_group_names (nullable) is None
        # and model_fields_set contains the field
        if self.authorized_group_names is None and "authorized_group_names" in self.model_fields_set:
            _dict["authorized_group_names"] = None

        # set to None if notes (nullable) is None
        # and model_fields_set contains the field
        if self.notes is None and "notes" in self.model_fields_set:
            _dict["notes"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateDatasetCollectionMultiBrainRegion from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "authorized_group_names": obj.get("authorized_group_names"),
                "name": obj.get("name"),
                "notes": obj.get("notes"),
                "dataset_definition": (
                    [MultiBrainRegionDatasetDefinition.from_dict(_item) for _item in obj["dataset_definition"]]
                    if obj.get("dataset_definition") is not None
                    else None
                ),
                "dataset_metadata": (
                    SingleDatasetSchemaNoBrainRegion.from_dict(obj["dataset_metadata"])
                    if obj.get("dataset_metadata") is not None
                    else None
                ),
            }
        )
        return _obj
