# coding: utf-8

"""
    Synapse DB

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.6.9
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class GeneExpression(str, Enum):
    """
    GeneExpression
    """

    """
    allowed enum values
    """
    KNOCK_MINUS_OUT = "knock-out"
    KNOCK_MINUS_IN = "knock-in"
    KNOCK_MINUS_DOWN = "knock-down"
    KNOCK_MINUS_SIDEWAYS = "knock-sideways"
    OVEREXPRESSION = "overexpression"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of GeneExpression from a JSON string"""
        return cls(json.loads(json_str))
